@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.93';
+our $VERSION = '0.94';
 
 use feature 'switch';
 
@@ -119,6 +119,10 @@ sub makefile_pl {
     return $self->main_file('Makefile.PL');
 }
 
+sub get_user {
+    return $ENV{LOGNAME} || $ENV{USER};
+}
+
 sub get_email {
     my $self = shift;
     my $email = $self->cfg->email;
@@ -138,7 +142,7 @@ sub get_name {
     my $self = shift;
 
     my $name;
-    my $user = $ENV{LOGNAME} || $ENV{USER};
+    my $user = $self->get_user;
     my $pwnam = getpwuid($<);
     die "Cannot determine current user\n" unless $pwnam;
     if ( defined $ENV{DEBFULLNAME} ) {
